/////////////////////////////////////////////////////////////////////////////
// Name:        src/msw/minifram.cpp
// Purpose:     wxMiniFrame
// Author:      Julian Smart
// Modified by:
// Created:     04/01/98
// Copyright:   (c) Julian Smart
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

// For compilers that support precompilation, includes "wx.h".
#include "wx/wxprec.h"

#if wxUSE_MINIFRAME

#include "wx/minifram.h"

wxIMPLEMENT_DYNAMIC_CLASS(wxMiniFrame, wxFrame);

#endif // wxUSE_MINIFRAME
